| Copyright | Will Thompson Iñaki García Etxebarria and Jonas Platte |
|---|---|
| License | LGPL-2.1 |
| Maintainer | Iñaki García Etxebarria (inaki@blueleaf.cc) |
| Safe Haskell | None |
| Language | Haskell2010 |
GI.GstVideo.Objects.VideoBufferPool
Contents
Description
No description available in the introspection data.
Synopsis
- newtype VideoBufferPool = VideoBufferPool (ManagedPtr VideoBufferPool)
- class (GObject o, IsDescendantOf VideoBufferPool o) => IsVideoBufferPool o
- toVideoBufferPool :: (MonadIO m, IsVideoBufferPool o) => o -> m VideoBufferPool
- noVideoBufferPool :: Maybe VideoBufferPool
- videoBufferPoolNew :: (HasCallStack, MonadIO m) => m VideoBufferPool
Exported types
newtype VideoBufferPool Source #
Memory-managed wrapper type.
Constructors
| VideoBufferPool (ManagedPtr VideoBufferPool) |
Instances
| GObject VideoBufferPool Source # | |
Defined in GI.GstVideo.Objects.VideoBufferPool Methods gobjectType :: IO GType # | |
| HasParentTypes VideoBufferPool Source # | |
Defined in GI.GstVideo.Objects.VideoBufferPool | |
| type ParentTypes VideoBufferPool Source # | |
Defined in GI.GstVideo.Objects.VideoBufferPool | |
class (GObject o, IsDescendantOf VideoBufferPool o) => IsVideoBufferPool o Source #
Type class for types which can be safely cast to VideoBufferPool, for instance with toVideoBufferPool.
Instances
| (GObject o, IsDescendantOf VideoBufferPool o) => IsVideoBufferPool o Source # | |
Defined in GI.GstVideo.Objects.VideoBufferPool | |
toVideoBufferPool :: (MonadIO m, IsVideoBufferPool o) => o -> m VideoBufferPool Source #
Cast to VideoBufferPool, for types for which this is known to be safe. For general casts, use castTo.
noVideoBufferPool :: Maybe VideoBufferPool Source #
A convenience alias for Nothing :: Maybe VideoBufferPool.
Methods
new
Arguments
| :: (HasCallStack, MonadIO m) | |
| => m VideoBufferPool | Returns: a new |
Create a new bufferpool that can allocate video frames. This bufferpool supports all the video bufferpool options.