| Copyright | Will Thompson Iñaki García Etxebarria and Jonas Platte |
|---|---|
| License | LGPL-2.1 |
| Maintainer | Iñaki García Etxebarria (inaki@blueleaf.cc) |
| Safe Haskell | None |
| Language | Haskell2010 |
GI.GstVideo.Objects.VideoFilter
Contents
Description
Provides useful functions and a base class for video filters.
The videofilter will by default enable QoS on the parent GstBaseTransform to implement frame dropping.
Synopsis
- newtype VideoFilter = VideoFilter (ManagedPtr VideoFilter)
- class (GObject o, IsDescendantOf VideoFilter o) => IsVideoFilter o
- toVideoFilter :: (MonadIO m, IsVideoFilter o) => o -> m VideoFilter
- noVideoFilter :: Maybe VideoFilter
Exported types
newtype VideoFilter Source #
Memory-managed wrapper type.
Constructors
| VideoFilter (ManagedPtr VideoFilter) |
Instances
| GObject VideoFilter Source # | |
Defined in GI.GstVideo.Objects.VideoFilter Methods gobjectType :: IO GType # | |
| HasParentTypes VideoFilter Source # | |
Defined in GI.GstVideo.Objects.VideoFilter | |
| type ParentTypes VideoFilter Source # | |
Defined in GI.GstVideo.Objects.VideoFilter | |
class (GObject o, IsDescendantOf VideoFilter o) => IsVideoFilter o Source #
Type class for types which can be safely cast to VideoFilter, for instance with toVideoFilter.
Instances
| (GObject o, IsDescendantOf VideoFilter o) => IsVideoFilter o Source # | |
Defined in GI.GstVideo.Objects.VideoFilter | |
toVideoFilter :: (MonadIO m, IsVideoFilter o) => o -> m VideoFilter Source #
Cast to VideoFilter, for types for which this is known to be safe. For general casts, use castTo.
noVideoFilter :: Maybe VideoFilter Source #
A convenience alias for Nothing :: Maybe VideoFilter.