| Copyright | Will Thompson Iñaki García Etxebarria and Jonas Platte |
|---|---|
| License | LGPL-2.1 |
| Maintainer | Iñaki García Etxebarria (inaki@blueleaf.cc) |
| Safe Haskell | None |
| Language | Haskell2010 |
GI.GstVideo.Structs.VideoConverter
Description
No description available in the introspection data.
Synopsis
- newtype VideoConverter = VideoConverter (ManagedPtr VideoConverter)
- noVideoConverter :: Maybe VideoConverter
- videoConverterFrame :: (HasCallStack, MonadIO m) => VideoConverter -> VideoFrame -> VideoFrame -> m ()
- videoConverterFree :: (HasCallStack, MonadIO m) => VideoConverter -> m ()
- videoConverterGetConfig :: (HasCallStack, MonadIO m) => VideoConverter -> m Structure
- videoConverterSetConfig :: (HasCallStack, MonadIO m) => VideoConverter -> Structure -> m Bool
Exported types
newtype VideoConverter Source #
Memory-managed wrapper type.
Constructors
| VideoConverter (ManagedPtr VideoConverter) |
Instances
| WrappedPtr VideoConverter Source # | |
Defined in GI.GstVideo.Structs.VideoConverter Methods wrappedPtrCalloc :: IO (Ptr VideoConverter) # | |
noVideoConverter :: Maybe VideoConverter Source #
A convenience alias for Nothing :: Maybe VideoConverter.
Methods
frame
Arguments
| :: (HasCallStack, MonadIO m) | |
| => VideoConverter |
|
| -> VideoFrame |
|
| -> VideoFrame |
|
| -> m () |
Convert the pixels of src into dest using convert.
Since: 1.6
free
Arguments
| :: (HasCallStack, MonadIO m) | |
| => VideoConverter |
|
| -> m () |
Free convert
Since: 1.6
getConfig
videoConverterGetConfig Source #
Arguments
| :: (HasCallStack, MonadIO m) | |
| => VideoConverter |
|
| -> m Structure | Returns: a |
Get the current configuration of convert.
setConfig
videoConverterSetConfig Source #
Arguments
| :: (HasCallStack, MonadIO m) | |
| => VideoConverter |
|
| -> Structure |
|
| -> m Bool | Returns: |
Set config as extra configuraion for convert.
If the parameters in config can not be set exactly, this function returns
False and will try to update as much state as possible. The new state can
then be retrieved and refined with videoConverterGetConfig.
Look at the GST_VIDEO_CONVERTER_OPT_* fields to check valid configuration
option and values.
Since: 1.6