| Copyright | Will Thompson Iñaki García Etxebarria and Jonas Platte |
|---|---|
| License | LGPL-2.1 |
| Maintainer | Iñaki García Etxebarria (inaki@blueleaf.cc) |
| Safe Haskell | None |
| Language | Haskell2010 |
GI.GstVideo.Structs.VideoDither
Contents
Description
GstVideoDither provides implementations of several dithering algorithms that can be applied to lines of video pixels to quantize and dither them.
Synopsis
- newtype VideoDither = VideoDither (ManagedPtr VideoDither)
- noVideoDither :: Maybe VideoDither
- videoDitherFree :: (HasCallStack, MonadIO m) => VideoDither -> m ()
- videoDitherLine :: (HasCallStack, MonadIO m) => VideoDither -> Ptr () -> Word32 -> Word32 -> Word32 -> m ()
Exported types
newtype VideoDither Source #
Memory-managed wrapper type.
Constructors
| VideoDither (ManagedPtr VideoDither) |
Instances
| WrappedPtr VideoDither Source # | |
Defined in GI.GstVideo.Structs.VideoDither | |
noVideoDither :: Maybe VideoDither Source #
A convenience alias for Nothing :: Maybe VideoDither.
Methods
free
Arguments
| :: (HasCallStack, MonadIO m) | |
| => VideoDither |
|
| -> m () |
Free dither
line
Arguments
| :: (HasCallStack, MonadIO m) | |
| => VideoDither |
|
| -> Ptr () |
|
| -> Word32 |
|
| -> Word32 |
|
| -> Word32 |
|
| -> m () |
Dither width pixels starting from offset x in line using dither.
y is the line number of line in the output image.