| Copyright | Will Thompson Iñaki García Etxebarria and Jonas Platte |
|---|---|
| License | LGPL-2.1 |
| Maintainer | Iñaki García Etxebarria (inaki@blueleaf.cc) |
| Safe Haskell | None |
| Language | Haskell2010 |
GI.GstVideo.Structs.VideoVBIParser
Description
A parser for detecting and extracting gstVideoAncillary data from
Vertical Blanking Interval lines of component signals.
Since: 1.16
Synopsis
- newtype VideoVBIParser = VideoVBIParser (ManagedPtr VideoVBIParser)
- noVideoVBIParser :: Maybe VideoVBIParser
- videoVBIParserAddLine :: (HasCallStack, MonadIO m) => VideoVBIParser -> Ptr Word8 -> m ()
- videoVBIParserCopy :: (HasCallStack, MonadIO m) => VideoVBIParser -> m VideoVBIParser
- videoVBIParserFree :: (HasCallStack, MonadIO m) => VideoVBIParser -> m ()
- videoVBIParserGetAncillary :: (HasCallStack, MonadIO m) => VideoVBIParser -> m (VideoVBIParserResult, VideoAncillary)
- videoVBIParserNew :: (HasCallStack, MonadIO m) => VideoFormat -> Word32 -> m VideoVBIParser
Exported types
newtype VideoVBIParser Source #
Memory-managed wrapper type.
Constructors
| VideoVBIParser (ManagedPtr VideoVBIParser) |
Instances
| BoxedObject VideoVBIParser Source # | |
Defined in GI.GstVideo.Structs.VideoVBIParser Methods boxedType :: VideoVBIParser -> IO GType # | |
noVideoVBIParser :: Maybe VideoVBIParser Source #
A convenience alias for Nothing :: Maybe VideoVBIParser.
Methods
addLine
videoVBIParserAddLine Source #
Arguments
| :: (HasCallStack, MonadIO m) | |
| => VideoVBIParser |
|
| -> Ptr Word8 |
|
| -> m () |
Provide a new line of data to the parser. Call videoVBIParserGetAncillary
to get the Ancillary data that might be present on that line.
Since: 1.16
copy
videoVBIParserCopy :: (HasCallStack, MonadIO m) => VideoVBIParser -> m VideoVBIParser Source #
No description available in the introspection data.
free
Arguments
| :: (HasCallStack, MonadIO m) | |
| => VideoVBIParser |
|
| -> m () |
Frees the parser.
Since: 1.16
getAncillary
videoVBIParserGetAncillary Source #
Arguments
| :: (HasCallStack, MonadIO m) | |
| => VideoVBIParser |
|
| -> m (VideoVBIParserResult, VideoAncillary) | Returns: |
Parse the line provided previously by videoVBIParserAddLine.
Since: 1.16
new
Arguments
| :: (HasCallStack, MonadIO m) | |
| => VideoFormat |
|
| -> Word32 |
|
| -> m VideoVBIParser | Returns: The new |
Create a new VideoVBIParser for the specified format and pixelWidth.
Since: 1.16